## Precision
precision_tree = '//opgg-static.akamaized.net/images/lol/perkStyle/8000.png?image=q_auto:best&v=1607480996'
fleet = '//opgg-static.akamaized.net/images/lol/perk/8021.png?image=q_auto:best&v=1607480996'
conqueror = '//opgg-static.akamaized.net/images/lol/perk/8010.png?image=q_auto:best&v=1607480996'
pta = '//opgg-static.akamaized.net/images/lol/perk/8005.png?image=q_auto:best&v=1607480996'
lethal_tempo = '//opgg-static.akamaized.net/images/lol/perk/8008.png?image=q_auto:best&v=1607480996'
overheal = '//opgg-static.akamaized.net/images/lol/perk/9101.png?image=q_auto:best&v=1607480996'
triumph = '//opgg-static.akamaized.net/images/lol/perk/9111.png?image=q_auto:best&v=1607480996'
pom = '//opgg-static.akamaized.net/images/lol/perk/8009.png?image=q_auto:best&v=1607480996'
alacrity = '//opgg-static.akamaized.net/images/lol/perk/9104.png?image=q_auto:best&v=1607480996'
tenacity = '//opgg-static.akamaized.net/images/lol/perk/9105.png?image=q_auto:best&v=1607480996'
bloodline = '//opgg-static.akamaized.net/images/lol/perk/9103.png?image=q_auto:best&v=1607480996'
coup = '//opgg-static.akamaized.net/images/lol/perk/8014.png?image=q_auto:best&v=1607480996'
cut_down = '//opgg-static.akamaized.net/images/lol/perk/8017.png?image=q_auto:best&v=1607480996'
last_stand = '//opgg-static.akamaized.net/images/lol/perk/8299.png?image=q_auto:best&v=1607480996'

## Domination
domination_tree = '//opgg-static.akamaized.net/images/lol/perkStyle/8100.png?image=q_auto:best&v=1607480996'
hob = '//opgg-static.akamaized.net/images/lol/perk/9923.png?image=q_auto:best&v=1607480996'
electrocute = '//opgg-static.akamaized.net/images/lol/perk/8112.png?image=q_auto:best&v=1607480996'
predator = '//opgg-static.akamaized.net/images/lol/perk/8124.png?image=,q_auto:best&v=1607480996'
dh = '//opgg-static.akamaized.net/images/lol/perk/8128.png?image=q_auto:best&v=1607480996'
cheapshot = '//opgg-static.akamaized.net/images/lol/perk/8126.png?image=q_auto:best&v=1607480996'
tob = '//opgg-static.akamaized.net/images/lol/perk/8139.png?image=q_auto:best&v=1607480996'
sudden_impact = '//opgg-static.akamaized.net/images/lol/perk/8143.png?image=q_auto:best&v=1607480996'
zombie_ward = '//opgg-static.akamaized.net/images/lol/perk/8136.png?image=q_auto:best&v=1607480996'
ghost_poro = '//opgg-static.akamaized.net/images/lol/perk/8120.png?image=q_auto:best&v=1607480996'
eyeball = '//opgg-static.akamaized.net/images/lol/perk/8138.png?image=q_auto:best&v=1607480996'
ravenous = '//opgg-static.akamaized.net/images/lol/perk/8135.png?image=q_auto:best&v=1607480996'
ingenious = '//opgg-static.akamaized.net/images/lol/perk/8134.png?image=q_auto:best&v=1607480996'
relentless = '//opgg-static.akamaized.net/images/lol/perk/8105.png?image=q_auto:best&v=1607480996'
ultimate = '//opgg-static.akamaized.net/images/lol/perk/8106.png?image=q_auto:best&v=1607480996'

## Sorcery
sorcery_tree = '//opgg-static.akamaized.net/images/lol/perkStyle/8200.png?image=q_auto:best&v=1607480996'
comet = '//opgg-static.akamaized.net/images/lol/perk/8229.png?image=q_auto:best&v=1607480996'
aery = '//opgg-static.akamaized.net/images/lol/perk/8214.png?image=q_auto:best&v=1607480996'
phase_rush = '//opgg-static.akamaized.net/images/lol/perk/8230.png?image=q_auto:best&v=1607480996'
orb = '//opgg-static.akamaized.net/images/lol/perk/8224.png?image=q_auto:best&v=1607480996'
manaflow = '//opgg-static.akamaized.net/images/lol/perk/8226.png?image=q_auto:best&v=1607480996'
nimbus = '//opgg-static.akamaized.net/images/lol/perk/8275.png?image=q_auto:best&v=1607480996'
transcendence = '//opgg-static.akamaized.net/images/lol/perk/8210.png?image=q_auto:best&v=1607480996'
celarity = '//opgg-static.akamaized.net/images/lol/perk/8234.png?image=q_auto:best&v=1607480996'
focus = '//opgg-static.akamaized.net/images/lol/perk/8233.png?image=q_auto:best&v=1607480996'
scorch = '//opgg-static.akamaized.net/images/lol/perk/8237.png?image=q_auto:best&v=1607480996'
water_walking = '//opgg-static.akamaized.net/images/lol/perk/8232.png?image=q_auto:best&v=1607480996'
gathering_storm = '//opgg-static.akamaized.net/images/lol/perk/8236.png?image=q_auto:best&v=1607480996'

## Resolve
resolve_tree = '//opgg-static.akamaized.net/images/lol/perkStyle/8400.png?image=q_auto:best&v=1607480996'
grasp = '//opgg-static.akamaized.net/images/lol/perk/8437.png?image=q_auto:best&v=1607480996'
aftershock = '//opgg-static.akamaized.net/images/lol/perk/8439.png?image=q_auto:best&v=1607480996'
guardian = '//opgg-static.akamaized.net/images/lol/perk/8465.png?image=q_auto:best&v=1607480996'
demolish = '//opgg-static.akamaized.net/images/lol/perk/8446.png?image=q_auto:best&v=1607480996'
font_of_life = '//opgg-static.akamaized.net/images/lol/perk/8463.png?image=q_auto:best&v=1607480996'
shield_bash = '//opgg-static.akamaized.net/images/lol/perk/8401.png?image=q_auto:best&v=1607480996'
conditioning = '//opgg-static.akamaized.net/images/lol/perk/8429.png?image=q_auto:best&v=1607480996'
second_wind = '//opgg-static.akamaized.net/images/lol/perk/8444.png?image=q_auto:best&v=1607480996'
boneplating = '//opgg-static.akamaized.net/images/lol/perk/8473.png?image=q_auto:best&v=1607480996'
overgrowth = '//opgg-static.akamaized.net/images/lol/perk/8451.png?image=q_auto:best&v=1607480996'
revitalize = '//opgg-static.akamaized.net/images/lol/perk/8453.png?image=q_auto:best&v=1607480996'
unflinching = '//opgg-static.akamaized.net/images/lol/perk/8242.png?image=q_auto:best&v=1607480996'

## Inspiration
inspiration_tree = '//opgg-static.akamaized.net/images/lol/perkStyle/8300.png?image=q_auto:best&v=1607480996'
glacial = '//opgg-static.akamaized.net/images/lol/perk/8351.png?image=q_auto:best&v=1607480996'
spellbook = '//opgg-static.akamaized.net/images/lol/perk/8360.png?image=q_auto:best&v=1607480996'
omnistone = '//opgg-static.akamaized.net/images/lol/perk/8358.png?image=q_auto:best&v=1607480996'
hexflash = '//opgg-static.akamaized.net/images/lol/perk/8306.png?image=q_auto:best&v=1607480996'
footwear = '//opgg-static.akamaized.net/images/lol/perk/8304.png?image=q_auto:best&v=1607480996'
stopwatch = '//opgg-static.akamaized.net/images/lol/perk/8313.png?image=q_auto:best&v=1607480996'
future = '//opgg-static.akamaized.net/images/lol/perk/8321.png?image=q_auto:best&v=1607480996'
minion = '//opgg-static.akamaized.net/images/lol/perk/8316.png?image=q_auto:best&v=1607480996'
biscuit = '//opgg-static.akamaized.net/images/lol/perk/8345.png?image=q_auto:best&v=1607480996'
cosmic = '//opgg-static.akamaized.net/images/lol/perk/8347.png?image=q_auto:best&v=1607480996'
approach_velocity = '//opgg-static.akamaized.net/images/lol/perk/8410.png?image=q_auto:best&v=1607480996'
timewarp = '//opgg-static.akamaized.net/images/lol/perk/8352.png?image=q_auto:best&v=1607480996'
