IRON_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377379497869353/Emblem_Iron.png"
SILVER_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791376720967368724/Emblem_Silver.png"
BRONZE_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377369566281748/Emblem_Bronze.png"
GOLD_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377378962047036/Emblem_Gold.png"
PLATINUM_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377382132547584/Emblem_Platinum.png"
DIAMOND_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377375622725652/Emblem_Diamond.png"
MASTER_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377381713248317/Emblem_Master.png"
GRANDMASTER_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377379607445564/Emblem_Grandmaster.png"
CHALLENGER_URL = "https://cdn.discordapp.com/attachments/787493493927968790/791377373044015154/Emblem_Challenger.png"

AATROX_PROFILE_URL = "http://ddragon.leagueoflegends.com/cdn/10.25.1/img/champion/Aatrox.png"